@@ -13,7 +13,7 @@ class NonWorkerStage(Stage):
             self.outlink.close()
 
 
-    def init(self, stage_id=0, stage_cls=None, cls_args=None, stage_type=NOR,
+    def init(self, stage_id=None, stage_cls=None, cls_args=None, stage_type=NOR,
              itypes=[None], otype=None):
         self.stage_id = stage_id
 
